@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_CRYPT_HASH_BASE_H__
-#define __MOBIUS_CRYPT_HASH_BASE_H__
+#ifndef MOBIUS_CRYPT_HASH_BASE_H
+#define MOBIUS_CRYPT_HASH_BASE_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -26,25 +26,34 @@ namespace mobius
 namespace crypt
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief abstract base class for hash functions implementation
-//!\author Eduardo Aguiar
+//! \brief abstract base class for hash functions implementation
+//! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class hash_base
 {
 public:
-  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief virtual destructor for safe inheritance
-  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   virtual ~hash_base () = default;
 
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // abstract methods
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   virtual void reset () noexcept = 0;
-  virtual const bytearray get_digest () = 0;
+  virtual void update (const mobius::bytearray&) noexcept = 0;
+  virtual mobius::bytearray get_digest () = 0;
+  virtual std::size_t get_block_size () const = 0;
+
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  //! \brief get digest as hex string
+  //! \return hex string
+  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  std::string
+  get_hex_digest ()
+  {
+    return get_digest ().to_hexstring ();
+  }
 };
 
-} // crypt namespace
-} // mobius namespace
+} // namespace crypt
+} // namespace mobius
 
 #endif
